@@ -1,5 +1,7 @@
 #' Returns amount of vehicles at each age
 #'
+#' @family age
+#'
 #' @description \code{\link{age_hdv}} returns amount of vehicles at each age
 #'
 #' @param x Numeric; numerical vector of vehicles with length equal to lines features of road network
@@ -14,6 +16,7 @@
 #' @param verbose Logical;  message with average age and total numer of vehicles
 #' @param namerows Any vector to be change row.names. For instance, name of
 #' regions or streets.
+#' @param time Character to be the time units as denominator, eg "1/h"
 #' @return dataframe of age distrubution of vehicles at each street
 #' @importFrom sf st_sf st_as_sf
 #' @note
@@ -46,7 +49,8 @@ age_hdv <- function (x,
                      bystreet = F,
                      net,
                      verbose = FALSE,
-                     namerows){
+                     namerows,
+                     time){
   # check na
   x[is.na(x)] <- 0
 
@@ -86,33 +90,44 @@ age_hdv <- function (x,
     df <- df*k
 
     if(verbose){
-    message(paste("Average age of",name, "is",
-                  round(sum(seq(1,agemax)*base::colSums(df)/sum(df)), 2),
-                  sep=" "))
-    message(paste("Number of",name, "is",
-                  round(sum(df, na.rm = T), 3),
-                  " [veh]",
-                  sep=" "))
-    cat("\n")
+      message(paste("Average age of",name, "is",
+                    round(sum(seq(1,agemax)*base::colSums(df)/sum(df)), 2),
+                    sep=" "))
+      message(paste("Number of",name, "is",
+                    round(sum(df, na.rm = T), 3),
+                    " [veh]",
+                    sep=" "))
+      cat("\n")
     }
+
     if(!missing(namerows)) {
       if(length(namerows) != nrow(df)) stop("length of namerows must be the length of number of rows of veh")
       row.names(df) <- namerows
     }
 
+
+
     # replace NA and NaN
     df[is.na(df)] <- 0
 
     if(!missing(net)){
       netsf <- sf::st_as_sf(net)
-      dfsf <- sf::st_sf(Vehicles(df*k), geometry = netsf$geometry)
+      if(!missing(time)){
+        dfsf <- sf::st_sf(Vehicles(df*k, time = time), geometry = netsf$geometry)
+      } else {
+        dfsf <- sf::st_sf(Vehicles(df*k), geometry = netsf$geometry)
+      }
       return(dfsf)
     } else {
-      return(Vehicles(df*k))
+      if(!missing(time)){
+        return(Vehicles(df*k, time = time))
+      } else {
+        return(Vehicles(df*k))
+      }
     }
 
     #bystreet = FALSE
-   } else {
+  } else {
     suca <- function (t) {1/(1 + exp(a*(t+b)))+1/(1 + exp(a*(t-b)))}
     anos <- seq(agemin,agemax)
     d <- (-1)*diff(suca(anos))
@@ -128,13 +143,13 @@ age_hdv <- function (x,
     df <- df*k
 
     if(verbose){
-    message(paste("Average age of",name, "is",
-                  round(sum(seq(1,agemax)*base::colSums(df)/sum(df)), 2),
-                  sep=" "))
-    message(paste("Number of",name, "is",
-                  round(sum(df, na.rm = T)/1000, 2),
-                  "* 10^3 veh", sep=" "))
-    cat("\n")
+      message(paste("Average age of",name, "is",
+                    round(sum(seq(1,agemax)*base::colSums(df)/sum(df)), 2),
+                    sep=" "))
+      message(paste("Number of",name, "is",
+                    round(sum(df, na.rm = T)/1000, 2),
+                    "* 10^3 veh", sep=" "))
+      cat("\n")
     }
 
     if(!missing(namerows)) {
@@ -145,12 +160,21 @@ age_hdv <- function (x,
     # replace NA and NaN
     df[is.na(df)] <- 0
 
+
     if(!missing(net)){
       netsf <- sf::st_as_sf(net)
-      dfsf <- sf::st_sf(Vehicles(df), geometry = netsf$geometry)
+      if(!missing(time)){
+        dfsf <- sf::st_sf(Vehicles(df, time = time), geometry = netsf$geometry)
+      } else {
+        dfsf <- sf::st_sf(Vehicles(df), geometry = netsf$geometry)
+      }
       return(dfsf)
     } else {
-      return(Vehicles(df))
-    }
+      if(!missing(time)){
+        return(Vehicles(df, time = time))
+      } else {
+        return(Vehicles(df))
+      }
     }
+  }
 }
